==> haskell-errors-2.3.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-Fk9dI6worBBG6Koxdzhvtu
key: errors-2.3.0-Fk9dI6worBBG6Koxdzhvtu
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: e0d4746d89a754b77970c248cf34a670
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.6.4/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/errors-2.3.0
hs-libraries: HSerrors-2.3.0-Fk9dI6worBBG6Koxdzhvtu
depends:
    base-4.12.0.0 exceptions-0.10.1-CTCpiJ1kUxgIR315GHArm5
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-1e1TIiTQmEX6EpFTXvT8Fs
key: errors-2.3.0-1e1TIiTQmEX6EpFTXvT8Fs
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: 1eb8e301208a6012b892534610940b65
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.6.4/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/errors-2.3.0
hs-libraries: HSerrors-2.3.0-1e1TIiTQmEX6EpFTXvT8Fs
depends:
    base-4.12.0.0 exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
